![PyPI - License](https://img.shields.io/pypi/l/yyjson.svg?style=flat-square)
![Tests](https://github.com/TkTech/py_yyjson/workflows/Run%20tests/badge.svg)

# py_yyjson

Exploratory python bindings for the [yyjson][] project.

This is a work in progress, and while technically it *works*, it needs to be
fleshed out, documentation needs to be added, tests, CI, etc...

[yyjson]: https://github.com/ibireme/yyjson
